{% extends "admin/import_export/import.html" %}
{% load i18n %}
{% load admin_urls %}

{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
&rsaquo; <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
&rsaquo; <a href="{% url opts|admin_urlname:'change' request.kwargs.survey.id %}">{{ request.kwargs.survey.id }}</a>
&rsaquo; {% trans "Import" %}
</div>
{% endblock %}

{% block confirm_import_form %}
<form action="{% url "admin:df_survey_survey_process_import_questions" request.kwargs.survey.id %}" method="POST">
    {% csrf_token %}
    {{ confirm_form.as_p }}
    <p>
        {% trans "Below is a preview of data to be imported. If you are satisfied with the results, click 'Confirm import'" %}
    </p>
    <div class="submit-row">
        <input type="submit" class="default" name="confirm" value="{% trans "Confirm import" %}">
    </div>
</form>
{% endblock %}
