# Generated by Django 4.2.6 on 2023-11-22 06:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("df_survey", "0002_auto_20231121_1208"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="question",
            options={"ordering": ["sequence"]},
        ),
        migrations.RemoveField(
            model_name="survey",
            name="questions",
        ),
        migrations.AddField(
            model_name="question",
            name="sequence",
            field=models.PositiveSmallIntegerField(
                default=1000, help_text="Display sequence, lower means first"
            ),
        ),
        migrations.AddField(
            model_name="question",
            name="survey",
            field=models.ForeignKey(
                default=1,
                on_delete=django.db.models.deletion.CASCADE,
                to="df_survey.survey",
            ),
            preserve_default=False,
        ),
        migrations.DeleteModel(
            name="SurveyQuestion",
        ),
    ]
